;+
; Project     :	STEREO - SSC
;
; Name        :	SSC_REMOVE_BAD_JPEG
;
; Purpose     :	Remove JPEGs of known bad images.
;
; Category    :	STEREO, Quicklook
;
; Explanation :	Reads in the bad image lists from SSW_SECCHI/data/badimages/
;               and deletes any corresponding JPEG images.  MPEG files are also
;               regenerated.
;
; Syntax      :	SSC_REMOVE_BAD_JPEG
;
; Examples    :	SSC_REMOVE_BAD_JPEG
;
; Inputs      :	None.
;
; Opt. Inputs :	None.
;
; Outputs     :	The STEREO browse pages are updated to reflect the removed
;               images.
;
; Opt. Outputs:	None.
;
; Keywords    :	DEBRIS  = If set, then space debris images are also removed.
;                         Currently only implemented for COR2.
;
; Calls       :	CONCAT_DIR, BREAK_FILE, BOOST_ARRAY, ALL_VALS, COR1_PBSERIES,
;               DATATYPE, SSC_MAKE_BROWSE
;
; Common      :	None.
;
; Restrictions:	EUVI not yet handled.
;
; Side effects:	None.
;
; Prev. Hist. :	None.
;
; History     :	Version 1, 4-Mar-2008, William Thompson, GSFC
;
; Contact     :	WTHOMPSON
;-
;
pro ssc_remove_bad_jpeg, debris=debris
;
badpath = concat_dir(getenv('SSW_SECCHI'), 'data')
badpath = concat_dir(badpath, 'badimages')
;
;  COR1-A
;
openr, unit, concat_dir(badpath, 'cor1a_bad.txt'), /get_lun
line = 'string'
while not eof(unit) do begin
    readf, unit, line
    if strmid(line,0,1) ne ';' then begin
        words = strsplit(line,/extract)
        break_file, words[0], disk0, dir0, name0
        boost_array, cor1a_bad, name0
    endif
endwhile
free_lun, unit
cor1a_bad = cor1a_bad[*]
cor1a_date = strmid(cor1a_bad,0,8)
;
;  COR1-B
;
openr, unit, concat_dir(badpath, 'cor1b_bad.txt'), /get_lun
line = 'string'
while not eof(unit) do begin
    readf, unit, line
    if strmid(line,0,1) ne ';' then begin
        words = strsplit(line,/extract)
        break_file, words[0], disk0, dir0, name0
        boost_array, cor1b_bad, name0
    endif
endwhile
free_lun, unit
cor1b_bad = cor1b_bad[*]
cor1b_date = strmid(cor1b_bad,0,8)
;
;  COR2-A
;
openr, unit, concat_dir(badpath, 'cor2a_mixed_imgs.txt'), /get_lun
line = 'string'
while not eof(unit) do begin
    readf, unit, line
    if strmid(line,0,1) ne ';' then begin
        words = strsplit(line,/extract)
        break_file, words[0], disk0, dir0, name0
        boost_array, cor2a_bad, name0
    endif
endwhile
free_lun, unit
if keyword_set(debris) then begin
    openr, unit, concat_dir(badpath, 'cor2a_debris.txt'), /get_lun
    line = 'string'
    while not eof(unit) do begin
        readf, unit, line
        if strmid(line,0,1) ne ';' then begin
            words = strsplit(line,/extract)
            break_file, words[0], disk0, dir0, name0
            boost_array, cor2a_bad, name0
        endif
    endwhile
    free_lun, unit
endif
cor2a_bad = cor2a_bad[*]
cor2a_date = strmid(cor2a_bad,0,8)
;
;  COR2-B
;
openr, unit, concat_dir(badpath, 'cor2b_mixed_imgs.txt'), /get_lun
line = 'string'
while not eof(unit) do begin
    readf, unit, line
    if strmid(line,0,1) ne ';' then begin
        words = strsplit(line,/extract)
        break_file, words[0], disk0, dir0, name0
        boost_array, cor2b_bad, name0
    endif
endwhile
free_lun, unit
if keyword_set(debris) then begin
    openr, unit, concat_dir(badpath, 'cor2b_debris.txt'), /get_lun
    line = 'string'
    while not eof(unit) do begin
        readf, unit, line
        if strmid(line,0,1) ne ';' then begin
            words = strsplit(line,/extract)
            break_file, words[0], disk0, dir0, name0
            boost_array, cor2b_bad, name0
        endif
    endwhile
    free_lun, unit
endif
cor2b_bad = cor2b_bad[*]
cor2b_date = strmid(cor2b_bad,0,8)
;
;  HI1-A
;
openr, unit, concat_dir(badpath, 'hi1a_bad.txt'), /get_lun
line = 'string'
while not eof(unit) do begin
    readf, unit, line
    if strmid(line,0,1) ne ';' then begin
        words = strsplit(line,/extract)
        break_file, words[0], disk0, dir0, name0
        boost_array, hi1a_bad, name0
    endif
endwhile
free_lun, unit
hi1a_bad = hi1a_bad[*]
hi1a_date = strmid(hi1a_bad,0,8)
;
;  HI1-B
;
openr, unit, concat_dir(badpath, 'hi1b_bad.txt'), /get_lun
line = 'string'
while not eof(unit) do begin
    readf, unit, line
    if strmid(line,0,1) ne ';' then begin
        words = strsplit(line,/extract)
        break_file, words[0], disk0, dir0, name0
        boost_array, hi1b_bad, name0
    endif
endwhile
free_lun, unit
hi1b_bad = hi1b_bad[*]
hi1b_date = strmid(hi1b_bad,0,8)
;
;  HI2-A
;
openr, unit, concat_dir(badpath, 'hi2a_bad.txt'), /get_lun
line = 'string'
while not eof(unit) do begin
    readf, unit, line
    if strmid(line,0,1) ne ';' then begin
        words = strsplit(line,/extract)
        break_file, words[0], disk0, dir0, name0
        boost_array, hi2a_bad, name0
    endif
endwhile
free_lun, unit
hi2a_bad = hi2a_bad[*]
hi2a_date = strmid(hi2a_bad,0,8)
;
;  HI2-B
;
openr, unit, concat_dir(badpath, 'hi2b_bad.txt'), /get_lun
line = 'string'
while not eof(unit) do begin
    readf, unit, line
    if strmid(line,0,1) ne ';' then begin
        words = strsplit(line,/extract)
        break_file, words[0], disk0, dir0, name0
        boost_array, hi2b_bad, name0
    endif
endwhile
free_lun, unit
hi2b_bad = hi2b_bad[*]
hi2b_date = strmid(hi2b_bad,0,8)
;
dates = all_vals([cor1a_date, cor1b_date, cor2a_date, cor2b_date, $
                  hi1a_date, hi1b_date, hi2a_date, hi2b_date])
for idate=0,n_elements(dates)-1 do begin
    date = dates[idate]
    process_date = 0
;
    path = getenv('STEREO_BROWSE') + '/' + strmid(date,0,4) + '/' + $
      strmid(date,4,2) + '/' + strmid(date,6,2)
    if file_exist(path) then begin
        bad_files = ''
        w = where(cor1a_date eq date, count)
        if count gt 0 then begin
            list = cor1_pbseries(date, 'a')
            if datatype(list) eq 'STC' then begin
                sz = size(list)
                break_file, list.filename, disk, dir, name
                cor1a_name = reform(name, sz[1:sz[0]])
            end else cor1a_name = ''
            for i=0,count-1 do begin
                ww = where(cor1a_bad[w[i]] eq cor1a_name, count1)
                if count1 gt 0 then begin
                    ww = floor(ww / 3)
                    bad_files = [bad_files, cor1a_name[*,ww]]
                end else bad_files = [bad_files, cor1a_bad[w[i]]]
            endfor
        endif
        w = where(cor1b_date eq date, count)
        if count gt 0 then begin
            list = cor1_pbseries(date, 'b')
            if datatype(list) eq 'STC' then begin
                sz = size(list)
                break_file, list.filename, disk, dir, name
                cor1b_name = reform(name, sz[1:sz[0]])
            end else cor1b_name = ''
            for i=0,count-1 do begin
                ww = where(cor1b_bad[w[i]] eq cor1b_name, count1)
                if count1 gt 0 then begin
                    ww = floor(ww / 3)
                    bad_files = [bad_files, cor1b_name[*,ww]]
                end else bad_files = [bad_files, cor1b_bad[w[i]]]
            endfor
        endif
        w = where(cor2a_date eq date, count)
        if count gt 0 then begin
            list = cor1_pbseries(date, 'a', /cor2)
            if datatype(list) eq 'STC' then begin
                sz = size(list)
                break_file, list.filename, disk, dir, name
                cor2a_name = reform(name, sz[1:sz[0]])
            end else cor2a_name = ''
            for i=0,count-1 do begin
                ww = where(cor2a_bad[w[i]] eq cor2a_name, count1)
                if count1 gt 0 then begin
                    ww = floor(ww / 3)
                    bad_files = [bad_files, cor2a_name[*,ww]]
                end else bad_files = [bad_files, cor2a_bad[w[i]]]
            endfor
        endif
        w = where(cor2b_date eq date, count)
        if count gt 0 then begin
            list = cor1_pbseries(date, 'b', /cor2)
            if datatype(list) eq 'STC' then begin
                sz = size(list)
                break_file, list.filename, disk, dir, name
                cor2b_name = reform(name, sz[1:sz[0]])
            end else cor2b_name = ''
            for i=0,count-1 do begin
                ww = where(cor2b_bad[w[i]] eq cor2b_name, count1)
                if count1 gt 0 then begin
                    ww = floor(ww / 3)
                    bad_files = [bad_files, cor2b_name[*,ww]]
                end else bad_files = [bad_files, cor2b_bad[w[i]]]
            endfor
        endif
        w = where(hi1a_date eq date, count)
        if count gt 0 then bad_files = [bad_files, hi1a_bad[w]]
        w = where(hi1b_date eq date, count)
        if count gt 0 then bad_files = [bad_files, hi1b_bad[w]]
        w = where(hi2a_date eq date, count)
        if count gt 0 then bad_files = [bad_files, hi2a_bad[w]]
        w = where(hi2b_date eq date, count)
        if count gt 0 then bad_files = [bad_files, hi2b_bad[w]]
        n_bad = n_elements(bad_files) - 1
        if n_bad gt 0 then begin
            bad_files = bad_files[1:*]
            for ibad=0,n_bad-1 do begin
                files = file_search(path, bad_files[ibad]+'*', count=count)
                if count gt 0 then begin
                    process_date = 1
                    file_delete, files, /verbose
                endif
            endfor
        endif
    endif
    if process_date then begin
        files = file_search(path, '*.mpg', count=count)
        if count gt 0 then file_delete, files, /verbose
        ssc_make_browse, date, /nosecchi, /mpeg_gen
    endif
endfor
end
