;+
; Project     :	STEREO - SSC
;
; Name        :	SSC_READ_VIEWPERIOD
;
; Purpose     :	Read in viewperiod files created by SSC_MAKE_VIEWPERIODS
;
; Category    :	STEREO, Operations, Orbit
;
; Explanation :	This routine is called from SSC_PARSE_NOAA_VIEWS to read in the
;               latest viewperiod files.
;
; Syntax      :	SSC_READ_VIEWPERIOD, FILENAME, VIEW_START, VIEW_END
;
; Examples    :	See ssc_parse_noaa_views.pro
;
; Inputs      :	FILENAME = The name of the viewperiod file to read.
;
; Opt. Inputs :	None
;
; Outputs     :	VIEW_START = List of viewperiod start times in TAI
;               VIEW_END   = List of end times in TAI
;
; Opt. Outputs:	None
;
; Keywords    :	None
;
; Calls       :	DELVARX, BOOST_ARRAY, UTC2TAI
;
; Common      :	None
;
; Restrictions:	None
;
; Side effects:	None
;
; Prev. Hist. :	None
;
; History     :	Version 1, 27-Nov-2023, William Thompson, GSFC
;
; Contact     :	WTHOMPSON
;-
;
pro ssc_read_viewperiod, filename, view_start, view_end
;
;  Open the file and read in the header.
;
openr, unit, filename, /get_lun
line = 'string'
for i=0,7 do readf, unit, line
;
;  Read in the dates from the file.
;
delvarx, view_start, view_end
while not eof(unit) do begin
    readf, unit, line
    words = strsplit(line, /extract)
    if n_elements(words) eq 3 then begin
        boost_array, view_start, words[0]
        boost_array, view_end,   words[1]
    endif
endwhile
free_lun, unit
;
;  Convert to TAI
;
view_start = utc2tai(view_start[*])
view_end   = utc2tai(view_end[*])
;
end
